@@ -1,6 +1,6 @@
 ;;; srht-git.el --- Sourcehut git                    -*- lexical-binding: t; -*-
 
-;; Copyright © 2022  Free Software Foundation, Inc.
+;; Copyright © 2022-2023  Free Software Foundation, Inc.
 
 ;; Created: <2022-04-26 Tue>
 
@@ -185,8 +185,9 @@ is assumed."
 
 (defun srht-git--annot (domain str)
   "Function to add annotations in the completions buffer for STR and DOMAIN."
-  (srht-annotation (seq _n created visibility)
-    (srht-git--candidates domain) str))
+  (pcase-let (((seq _n created visibility)
+               (assoc str (srht-git--candidates domain))))
+    (srht-annotation str visibility created)))
 
 (defun srht-git--repo-name-read (domain)
   "Read a repository name in the minibuffer, with completion.
@@ -209,7 +210,10 @@ and domain name DOMAIN."
       (201 (srht-with-json-read-from-string body
              (map (:name repo-name)
                   (:owner (map (:canonical_name username))))
-             (srht-kill-link domain 'git username repo-name)
+             (let ((url (srht--make-uri
+                         domain 'git (format "/%s/%s" username repo-name) nil)))
+               (srht-copy-url url)
+               (srht-browse-url url))
              (srht-retrive (srht-git-repos domain)
                            :then (lambda (resp)
                                    (srht-put srht-git-repos domain resp)))))
