@@ -1,14 +1,14 @@
 ;;; srht.el --- Sourcehut               -*- lexical-binding: t; -*-
 
-;; Copyright © 2022  Free Software Foundation, Inc.
+;; Copyright © 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Aleksandr Vityazev <avityazev@posteo.org>
 ;; Maintainer: Aleksandr Vityazev <avityazev@posteo.org>
 ;; Keywords: comm vc
-;; Package-Version: 0.2
+;; Package-Version: 0.3
 ;; Homepage: https://sr.ht/~akagi/srht.el/
 ;; Keywords: comm
-;; Package-Requires: ((emacs "27.1") (plz "0.1"))
+;; Package-Requires: ((emacs "27.1") (plz "0.7"))
 
 ;; This file is part of GNU Emacs.
 
@@ -58,6 +58,11 @@ It is necessary to use Oauth personal token not Oauth2."
   :type 'string
   :group 'srht)
 
+(defcustom srht-browse-url-after-kill nil
+  "When t open the url copied to `kill-ring' url `browse-url'."
+  :type 'boolean
+  :group 'srht)
+
 (defun srht-token ()
   "Lookup variable `srht-token' if needed and return it.
 If variable `srht-token' is nil or cannot be looked up or is empty, signal
@@ -209,11 +214,15 @@ completion function is trying to complete."
              (complete-with-action action collection string pred)))))
     (completing-read prompt table nil t)))
 
-(defun srht-kill-link (domain service name resource)
-  "Make URL the latest kill in the kill ring.
-Constructed from DOMAIN, SERVICE, NAME and RESOURCE."
-  (kill-new (srht--make-uri domain service (format "/%s/%s" name resource) nil))
-  (message "URL in kill-ring"))
+(defun srht-copy-url (url)
+  "Make URL the latest kill in the kill ring."
+  (kill-new url)
+  (message "Copied \"%s\" into clipboard" url))
+
+(defun srht-browse-url (url)
+  "Browse URL."
+  (when srht-browse-url-after-kill
+    (browse-url url)))
 
 (defmacro srht-with-json-read-from-string (string pattern &rest body)
   "Read the JSON object contained in STRING.
@@ -249,22 +258,14 @@ For the existing PLIST for the DOMAIN domain name."
   (declare (indent 1))
   `(when ,val (setq ,plist (plist-put ,plist (intern ,domain) ,val))))
 
-(defmacro srht-annotation (pattern candidates str)
-  "Annotate STR.
-The value of the first CANDIDATES elements whose car equal STR is bind
-to pcase PATTERN."
+(defun srht-annotation (str visibility created)
+  "Return an annotation for STR using VISIBILITY and CREATED."
   (declare (indent 1))
-  (let ((bb (gensym "bb"))
-        (sb (gensym "sb"))
-        (l (gensym "l")))
-    `(pcase-let* ((,pattern (assoc ,str ,candidates))
-                  (,l (- 40 (length (substring-no-properties ,str))))
-                  (,bb (make-string ,l (string-to-char " ")))
-                  (,sb (cond
-                        ((string= visibility "public") "      ")
-                        ((string= visibility "private") "     ")
-                        ((string= visibility "unlisted") "    "))))
-       (concat ,bb (format "%s%s%s" visibility ,sb created)))))
+  (let* ((ws-char (string-to-char " "))
+         (len (- 40 (length (substring-no-properties str))))
+         (blank (make-string (if (> len 1) len 1) ws-char)))
+    (concat blank visibility (make-string (- 12 (length visibility)) ws-char)
+            created)))
 
 (provide 'srht)
 ;;; srht.el ends here
